<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>閉じる (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>セッション (&amp;S)</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>詳細</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>警告を無視する</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>全 %Ln 単語</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>全 %Ln 分</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>全 %Ln 分中 %L1%</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>全 %Ln 単語中 %L1%</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>日毎の進捗</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>最長連続執筆期間</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>現在の連続執筆期間</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n 日</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>一日の目標の %L1%</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>言語の変更</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(無題 %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (読み込み専用)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; を保存できませんでした。</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; を上書きすることができませんでした。</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>ファイル名の変更</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; の名前を変更できませんでした。</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>ファイルを再読み込みしますか？</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>ファイル %1 を再読み込みしますか？</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>保存されていない変更はすべて失われます。</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>再読み込み</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>無題 %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>問い合わせ</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>プレーン・テキストとして保存した場合、すべての書式が失われます。よろしいですか？</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>ファイルが変更されています</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>他のプログラムによりファイル %1 は変更されています。</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>ファイルを読み込み直しますか？</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>再読み込み</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>無視</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>ファイルが削除されました</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>他のプログラムによりファイル %1 は削除されました。</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>ファイルを保存、または閉じますか？</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>アーカイブを開けませんでした。</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>検索する文字列:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>置換後の文字列:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>大文字と小文字を区別しない</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>単語単位で探す</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>正規表現</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>前を検索</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>次を検索</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>検索 (&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>置換 (&amp;R)</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>すべて置換 (&amp;A)</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>置換</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>%n 件置換しますか？</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>見つかりませんでした。</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument 文書</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>リッチ テキスト形式</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>テキスト文書</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>すべてのファイル</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>サポートされているすべてのファイル</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>スペルチェック...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(修正候補は見つかりませんでした)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>画像の選択</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>画像</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>言語の選択:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;システムの言語&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>注意</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>言語の変更を反映させるためにアプリケーションを再起動してください。</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>アーカイブを開けませんでした。</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>統計</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>ツール バー</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>スペルチェック</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>辞書の選択</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>アーカイブを開けませんでした。</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>このアーカイブには有効な辞書が含まれていません。</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>ショートカット一覧</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>ショートカットがいくつかバッティングしています。続行してもよろしいですか？</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>&quot;%1&quot; という名前の辞書は既にあります。置き換えても良いですか？</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>一日の目標</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>分:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>語:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>カーソル位置を常に縦方向の中央にする</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>挿入モードでもブロック形のカーソルを使う</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>フォントをなめらかにする</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>タイプライター音を再生する</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>スマート引用符:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>二重</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>一重</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>シーン一覧</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>ディバイダー:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>カーソル位置を記憶する</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>単語数</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>ページ数</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>段落数</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>文字数</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>文字</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>段落</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>単語数カウント・アルゴリズム</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>今日の進捗状況を0にリセットしますか？</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>プレーンテキストにも BOM を追加する</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>デフォルトの形式:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>本日分をリセット</translation>
    </message>
    <message>
        <source>History</source>
        <translation>履歴</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>履歴を保存する</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>連続執筆期間の表示</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>連続執筆期間の最小値:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>単語の境界を認識する</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>文字数を 6 で割る</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>一文字ごとに単語として数える</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>ページ数カウント・アルゴリズム</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>スタイル</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>アイコンのみ</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>文字のみ</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>アイコンの横に文字</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>アイコンの下に文字</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>文字の位置:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>アクション</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>上へ移動</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>下へ移動</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>セパレーターを追加</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>アクション</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>タイプするごとにチェックする</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>大文字を無視する</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>数字が含まれる単語を無視する</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>言語</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>ユーザー辞書</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>現在の辞書を削除しますか？</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>ユーザインタフェース</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>常にスクロール・バーを表示</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>常にトップ・バーを表示</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>常にボトム・バーを表示</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>サポートしていないリッチ テキスト形式です。</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>ファイルの最後に到達しました。</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>シーンをひとつ上に移動</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>シーン・リストの表示の切り替え</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>シーン・リストの表示 (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>シーン・リストの非表示 (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>絞込み</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>シーンをひとつ下に移動</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>シーン・リストのリサイズ</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>デフォルト</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>セッションの管理</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>セッション (&amp;S)</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>名前の変更</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>切り替え</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>新しいセッション</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>セッションの複製</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>セッション名の変更</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>選択中のセッションを削除しますか？</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>セッション名:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>指定したセッション名は既にあります。</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>新規 (&amp;N)...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>管理 (&amp;M)...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>消去</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>デフォルトに戻す</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>ショートカット:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>引用符の置換...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>お待ちください</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>スペルチェック</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>追加 (&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>無視 (&amp;I)</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>すべて無視 (&amp;G)</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>変更 (&amp;C)</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>すべて変更 (&amp;H)</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>辞書にないもの:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>変更後:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>スペルチェック中です...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>お待ちください</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>ファイルの先頭からチェックを続けますか？</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>スペルチェックが終わりました。</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>シンボル一覧</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>最近使ったシンボル</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>すべてのシンボル</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>詳細</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>挿入</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>ブロック</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>スクリプト</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>無題 %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>イメージなし</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>並べて表示</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>中央に表示</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>画面に合わせて伸縮</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>ページ縦幅に合わせる</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>ページ横幅に合わせる</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>不透明度:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>位置:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>幅:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>テキスト背景の角を丸める</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>半径:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>テキスト背景をぼやかす:</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>テキスト背景の影</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>垂直方向の距離:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>マージン</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>ウィンドウ:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>ページ:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>最初の行をインデントする</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>上に:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>下に:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>テーマを編集</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>ウィンドウの背景</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>画像の配置:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>背景色:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>画像:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> ピクセル</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左寄せ</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>テキスト背景</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右寄せ</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>フォント:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>スペルミス:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>行間のスペース</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>シングル</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5倍</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>2倍</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>プロポーショナル</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>高さ:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>段落間のマージン</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>タブ幅:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>新しいテーマ</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>テーマ</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>デフォルト</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Gentle Blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Old School</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Space Dreams</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Writing Desk</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>カスタム</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>インポート</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>テーマ &apos;%1&apos; を削除しますか？</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>テーマ (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>テーマのインポート</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>テーマのエクスポート</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Bitter Skies</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Enchantment</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Spy Games</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Tranquility</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>タイマーを削除しますか？</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;単語数:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;ページ数:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;段落数:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;文字数:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>時間で指定</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>時刻で指定</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>時間:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>時刻:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>アラーム</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>種類:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>メモ:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>タイマーはありません。</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>タイマー</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新規作成</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>履歴</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>タイマーの編集を中止しますか？</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>テーマを読み込んでいます</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>音声を読み込んでいます</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>無題</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>FocusWriter について</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>A simple fullscreen word processor</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>文字数: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>ページ数: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>段落数: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>単語数: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 を開いています</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(無題 %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>全文書の表示</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>次のドキュメントへ切り替える</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>前のドキュメントへ切り替える</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>最初のドキュメントへ切り替える</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>最後のドキュメントへ切り替える</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>%1 へ切り替える</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>設定を読み込んでいます</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>緊急用のキャッシュに書き込むことができませんでした。</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter は正常に終了できませんでした。</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>緊急用のキャッシュから復活させますか？</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>いくつかのファイルが開けませんでした。</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>いくつかをファイルを読み取り専用で開きました。</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; はキャッシュより新しいようです。</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>新しいファイルの上から書き込みますか？</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>変更を保存しますか？</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>閉じる前にファイル %1 へ加えた変更を保存しますか？</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>保存しない場合、加えた変更は失われます。</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>タイプライター音を読み込めませんでした。</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>ファイル (&amp;F)</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新規作成 (&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>開く (&amp;O)...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>再読み込み (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>保存 (&amp;S)...</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>名前を付けて保存 (&amp;A)...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>名前の変更 (&amp;R)...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>すべて保存 (&amp;L)</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>セッションの管理</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>新規セッション</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>印刷 (&amp;P)...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>閉じる (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>終了 (&amp;Q)</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編集 (&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>元に戻す (&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>やり直し (&amp;R)</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>切り取り (&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>コピー (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>貼り付け (&amp;P)</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>書式を無視して貼り付け</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>すべて選択 (&amp;A)</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>シーンの選択 (&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>書式 (&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>太字 (&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>斜体 (&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>下線 (&amp;U)</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>取り消し線 (&amp;K)</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>下付き文字 (&amp;E)</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>上付き文字 (&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>左揃え (&amp;L)</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>中央揃え (&amp;C)</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>右揃え (&amp;R)</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>均等割付 (&amp;J)</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>インデントを減らす (&amp;D)</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>インデントを増やす (&amp;N)</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>左から右へ (&amp;F)</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>右から左へ (&amp;G)</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>ツール (&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>検索 (&amp;F)...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>次を検索 (&amp;N)</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>前を検索 (&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>置換 (&amp;R)...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>スマート引用符 (&amp;Q)</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>文書全体に適用 (&amp;D)</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>選択範囲に適用 (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>スペルチェック (&amp;S)...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>言語の変更 (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>タイマー (&amp;T)...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>シンボル (&amp;Y)...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>日毎の進捗 (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>設定 (&amp;S)</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>ツール バーを表示 (&amp;T)</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>メニュー項目のアイコンを表示 (&amp;M)</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>フォーカスされた文字 (&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>全画面表示 (&amp;F)</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>最小化 (&amp;I)</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>テーマ (&amp;T)...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>設定 (&amp;P)...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>フォーカスの無効</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>一行フォーカス</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>三行フォーカス</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>段落 (&amp;P)</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>段落フォーカス</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ (&amp;H)</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Application &amp;Language...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>いくつかのファイルがサポートされていない形式のため開くことができませんでした。</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>オフ (&amp;O)</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>一行 (&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>三行 (&amp;T)</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>FocusWriter について (&amp;A)</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Qt について (&amp;Q)</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>ページ設定</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>見出し (&amp;H)</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>見出しレベル1 (&amp;1)</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>見出しレベル2 (&amp;2)</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>見出しレベル3 (&amp;3)</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>見出しレベル4 (&amp;4)</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>見出しレベル5 (&amp;5)</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>見出しレベル6 (&amp;6)</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>通常 (&amp;N)</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>文書全体にスマート引用符を適用</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>選択範囲にスマート引用符を適用</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
